import React, {Component} from 'react'
import PropTypes from 'prop-types'
import { is, fromJS } from 'immutable'
import { Radio, Modal, message } from 'antd'
import { PaperClipOutlined, DeleteOutlined, CopyOutlined } from '@ant-design/icons'

import InputForm from './inputform'
import './index.scss'

class SourceComponent extends Component {
  static propTpyes = {
    type: PropTypes.string,
    placement: PropTypes.any,
    onChange: PropTypes.func
  }

  state = {
    url: '',
    visible: ''
  }

  UNSAFE_componentWillMount () {
    const { value, initialValue } = this.props
    let val = ''

    if (value) {
      val = value
    } else if (initialValue) {
      val = initialValue
    } else if (this.props['data-__meta']) {
      val = this.props['data-__meta'].initialValue || ''
    }

    this.setState({
      url: val,
    })
  }

  shouldComponentUpdate (nextProps, nextState) {
    return !is(fromJS(this.state), fromJS(nextState)) || nextProps.type !== this.props.type
  }

  deleteUrl = () => {
    this.setState({url: ''})
    this.props.onChange('')
  }

  copyUrl = () => {
    const { url } = this.state

    let oInput = document.createElement('input')
    oInput.value = url
    document.body.appendChild(oInput)
    oInput.select()
    document.execCommand('Copy')
    document.body.removeChild(oInput)
    message.success('复制成功。')
  }

  handleChange = (key) => {
    this.setState({visible: key})
  }

  popSubmit = () => {
    let url = ''
    if (this.inputWrap && this.inputWrap.state.url) {
      url = this.inputWrap.state.url
    }

    this.setState({visible: '', url})
    this.props.onChange(url)
  }

  render () {
    const { url, visible } = this.state
    const { type } = this.props
    let name = url ? url.slice(url.lastIndexOf('/') + 1) : ''
    // url !== '@icon@'

    return (
      <div className="mk-source-wrap">
        {!url ? <Radio.Group>
          <Radio.Button value="input" size="small" onClick={() => this.handleChange('input')}>输入</Radio.Button>
          <Radio.Button value="upload" size="small" onClick={() => this.handleChange('upload')}>上传</Radio.Button>
          <Radio.Button value="system" size="small" onClick={() => this.handleChange('system')}>系统</Radio.Button>
        </Radio.Group> : null}
        {url && type === 'video' ? <div className="mk-source-item-info">
          <PaperClipOutlined />
          <a target="_blank" rel="noopener noreferrer" href={url.replace(/@mywebsite@\//ig, window.GLOB.baseurl)}>{name}</a>
          <CopyOutlined title="复制链接" onClick={this.copyUrl}/>
          <DeleteOutlined title="删除文件" onClick={this.deleteUrl}/>
        </div> : null}
        {url && type !== 'video' && url !== '@icon@' ? <div className="mk-source-item-info picture">
          <img src={url.replace(/@mywebsite@\//ig, window.GLOB.baseurl)} alt="" />
          <a target="_blank" rel="noopener noreferrer" href={url.replace(/@mywebsite@\//ig, window.GLOB.baseurl)}>{name}</a>
          <CopyOutlined title="复制链接" onClick={this.copyUrl}/>
          <DeleteOutlined title="删除文件" onClick={this.deleteUrl}/>
        </div> : null}
        {url && type !== 'video' && url === '@icon@' ? <div className="mk-source-item-info avatar">
          <span className="mk-avatar">{name}</span>
          <DeleteOutlined title="删除文件" onClick={this.deleteUrl}/>
        </div> : null}
        <Modal
          visible={!!visible}
          width={visible !== 'system' ? 650 : 1000}
          closable={false}
          maskClosable={false}
          okText="确定"
          cancelText="取消"
          onOk={this.popSubmit}
          onCancel={() => {this.setState({visible: ''})}}
          destroyOnClose
        >
          <InputForm type={type === 'picture' ? 'image' : type} keyword={visible} ref={dom => { this.inputWrap = dom }} />
        </Modal>
      </div>
    )
  }
}

export default SourceComponent